=========
Factories
=========


Curves
======

.. automodule:: splipy.curve_factory
   :members:


Surfaces
========

.. automodule:: splipy.surface_factory
   :members:


Volumes
=======

.. automodule:: splipy.volume_factory
   :members:
